=======
History
=======


_._._ (2019-__-__)
------------------

* Made a variety of documentation improvements.

0.1.1 (2019-02-22)
------------------

* Jesse discovered that the code was incorrectly testing for
  executability of the ``$ISISROOT/bin/xml/*xml`` files instead of
  the ``$ISISROOT/bin/*`` program files, and issued a PR that
  fixed it.


0.1.0 (2019-02-20)
------------------

* Initial creation finished. Time to share.

0.0.0 (2019-02-12)
------------------

* Started project.


Version Numbering
-----------------

The kalasiris library follows the `Semantic Versioning 2.0.0
specification <https://semver.org>`_, such that released kalasiris
version numbers follow this pattern: ``{major}.{minor}.{patch}``.
